@@ -13,13 +13,14 @@ else:
     build_dir = os.path.join(parent_dir, "frontend/build")
     _component_func = components.declare_component("searchbar_component", path=build_dir)
 
-def searchbar(placeholder="Search...", key=None, suggestions=None, return_selection_only=True, show_clear_button=True, show_plus_button=True, style_overrides=None):
+def searchbar(placeholder="Search...", key=None, suggestions=None, return_selection_only=True, show_clear_button=True, show_plus_button=True, keep_open_on_plus=False, style_overrides=None):
     component_value = _component_func(
         placeholder=placeholder,
         suggestions=suggestions,
         return_selection_only=return_selection_only,
         show_clear_button=show_clear_button,
         show_plus_button=show_plus_button,
+        keep_open_on_plus=keep_open_on_plus,
         style_overrides=style_overrides,
         key=key,
         default=None
